==> haskell-monad-parallel-0.8-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-parallel
version:              0.8
visibility:           public
id:                   monad-parallel-0.8-8PJISqW4eg7Lj5A3EjPsB4
key:                  monad-parallel-0.8-8PJISqW4eg7Lj5A3EjPsB4
license:              BSD-3-Clause
copyright:            (c) 2010-2022 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://hub.darcs.net/blamario/SCC.wiki/
synopsis:             Parallel execution of monadic computations
description:
    This package defines classes of monads that can perform multiple executions in parallel and combine their results. For
    any monad that'\''s an instance of the class, the package re-implements a subset of the Control.Monad interface, but with
    parallel execution.

category:             Control, Monads
abi:                  9600dbfe60e5c9e904d829eed8ee27d4
exposed:              True
exposed-modules:      Control.Monad.Parallel
import-dirs:          /usr/lib/ghc-9.0.2/site-local/monad-parallel-0.8
library-dirs:         /usr/lib/ghc-9.0.2/site-local/monad-parallel-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-parallel
hs-libraries:         HSmonad-parallel-0.8-8PJISqW4eg7Lj5A3EjPsB4
depends:
    base-4.15.1.0 parallel-3.2.2.0-D2aleEa2VnPBr164BdKnms
    transformers-0.5.6.2
    transformers-compat-0.7.2-ZzSHjvD4flB2ChCq5TVbH

haddock-interfaces:
    /usr/share/doc/haskell-monad-parallel/html/monad-parallel.haddock

haddock-html:         /usr/share/doc/haskell-monad-parallel/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-parallel-0.8-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-parallel
version:              0.8
visibility:           public
id:                   monad-parallel-0.8-Asv4bXDWZRP5CWAwOPs1ie
key:                  monad-parallel-0.8-Asv4bXDWZRP5CWAwOPs1ie
license:              BSD-3-Clause
copyright:            (c) 2010-2022 Mario Blazevic
maintainer:           blamario@yahoo.com
author:               Mario Blazevic
homepage:             https://hub.darcs.net/blamario/SCC.wiki/
synopsis:             Parallel execution of monadic computations
description:
    This package defines classes of monads that can perform multiple executions in parallel and combine their results. For
    any monad that'\''s an instance of the class, the package re-implements a subset of the Control.Monad interface, but with
    parallel execution.

category:             Control, Monads
abi:                  a472e616d2f62247f3d17fc4509e1359
exposed:              True
exposed-modules:      Control.Monad.Parallel
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-parallel-0.8
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-parallel-0.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-parallel
hs-libraries:         HSmonad-parallel-0.8-Asv4bXDWZRP5CWAwOPs1ie
depends:
    base-4.16.4.0 parallel-3.2.2.0-KgDyPHm89eYAjQsIhXthC1
    transformers-0.5.6.2
    transformers-compat-0.7.2-9ApmiRwA3hS7UuQpOomcS

haddock-interfaces:
    /usr/share/doc/haskell-monad-parallel/html/monad-parallel.haddock

haddock-html:         /usr/share/doc/haskell-monad-parallel/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
